@@ -27,6 +27,9 @@ $screensavers->{'biof'} 	= '  GL:                   "BioF"  biof --root
 $screensavers->{'busyspheres'} 	= '  GL:            "BusySpheres"  busyspheres --root                          \\n\\';
 $screensavers->{'spirographx'} 	= '  GL:            "SpirographX"  spirographx --root                          \\n\\';
 $screensavers->{'matrixview'} 	= '  GL:             "MatrixView"  matrixview --root                           \\n\\';
+$screensavers->{'lorenz'}	= '  GL:                 "Lorenz"  lorenz --root                               \\n\\';
+$screensavers->{'drempels'}	= '  GL:               "Drempels"  drempels --root                             \\n\\';
+$screensavers->{'feedback'}	= '  GL:               "Feedback"  feedback --root                             \\n\\';
 
 open XSCREENSAVER, "$ENV{'HOME'}/.xscreensaver";
 my @xscreensaver_config_file = <XSCREENSAVER>;
